@@ -19,17 +19,16 @@ class SwiftClientFactory():
                                interface=args.os_interface,
                                region_name=args.os_region_name)
 
-    def _session(self, auth_url=None, project_name=None,
+    def _session(self, auth_url=None, project_id=None, project_name=None,
                  project_domain_id=None, region_name=None):
         fake_argv = []
-        if auth_url:
-            fake_argv.extend(['--os-auth-url', auth_url])
-        if project_name:
-            fake_argv.extend(['--os-project-name', project_name])
-        if project_domain_id:
-            fake_argv.extend(['--os-project-domain-id', project_domain_id])
-        if region_name:
-            fake_argv.extend(['--os-region-name', region_name])
+        for value, name in [(auth_url, 'os-auth-url'),
+                            (project_id, 'os-project-id'),
+                            (project_name, 'os-project-name'),
+                            (project_domain_id, 'os-project-domain-id'),
+                            (region_name, 'os-region-name')]:
+            if value:
+                fake_argv.extend([f'--{name}', value])
 
         parser = argparse.ArgumentParser()
         loading.cli.register_argparse_arguments(
@@ -56,13 +55,14 @@ class SwiftClientFactory():
 
     @lru_cache(maxsize=128)
     def scoped(self, **kwargs):
-        if not kwargs.get('project_name'):
+        if not kwargs.get('project_id'):
             projects = self.all_projects(auth_url=kwargs.get('auth_url'))
             if projects:
                 # Choose first one by default
                 # TODO(jason): this could be smarter and look at last project
                 # the user was interacting w/ in the plugin somehow.
                 project = projects[0]
+                kwargs['project_id'] = project['id']
                 kwargs['project_name'] = project['name']
                 kwargs['project_domain_id'] = project['domain_id']
 
