@@ -8,6 +8,7 @@ class SwiftBaseHandler(IPythonHandler):
     DELIMITER = '/'
 
     AUTH_URL_HEADER = 'x-auth-url'
+    PROJECT_ID_HEADER = 'x-project-id'
     PROJECT_NAME_HEADER = 'x-project-name'
     PROJECT_DOMAIN_ID_HEADER = 'x-project-domain-id'
     REGION_NAME_HEADER = 'x-region-name'
@@ -73,10 +74,11 @@ class SwiftBaseHandler(IPythonHandler):
     def swift_client(self):
         hdr = self.request.headers
         return self.client_factory.scoped(
-            auth_url=hdr.get(self.AUTH_URL_HEADER),
+            project_id=hdr.get(self.PROJECT_ID_HEADER),
             project_name=hdr.get(self.PROJECT_NAME_HEADER),
-            project_domain_id=hdr.get(self.PROJECT_NAME_HEADER),
-            region_name=hdr.get(self.REGION_NAME_HEADER)
+            project_domain_id=hdr.get(self.PROJECT_DOMAIN_ID_HEADER),
+            auth_url=hdr.get(self.AUTH_URL_HEADER),
+            region_name=hdr.get(self.REGION_NAME_HEADER),
         )
 
     def swift_path(self, path):
@@ -97,5 +99,5 @@ class SwiftBaseHandler(IPythonHandler):
             return None
         # Grab project name from the current auth context
         auth = self.swift.session.auth
-        project_name = auth.project_name
+        project_name = auth._project_name
         return conf.root_container.format(project_name=project_name)
