@@ -21,9 +21,19 @@ class SwiftConfigHandler(SwiftBaseHandler, APIHandler):
         conf = self.swift_config
 
         try:
-            projects = self.client_factory.all_projects()
+            projects = [
+                dict(
+                    name=p['name'],
+                    id=p['id'],
+                    domain_id=p['domain_id'],
+                ) for p in self.client_factory.all_projects()
+            ]
             # Sort by name to be nice
             projects.sort(key=lambda p: p['name'])
+            if projects:
+                default_project_id = projects[0]['id']
+            else:
+                default_project_id = None
         except HttpError as err:
             self.log.warn('Failed to fetch list of projects for user: {}'.format(err.details))
             projects = []
@@ -32,5 +42,6 @@ class SwiftConfigHandler(SwiftBaseHandler, APIHandler):
         self.set_header('content-type', 'application/json')
         self.finish(json.dumps(dict(
             max_file_size_bytes=conf.max_file_size_bytes,
-            projects=projects
+            projects=projects,
+            default_project_id=default_project_id,
         )))
