@@ -1,7 +1,8 @@
 import json
 from jupyterlab_swift.handler.base import SwiftBaseHandler
 from jupyterlab_swift.handler.decorator import swift_proxy
-from keystoneauth1.exceptions.http import NotFound, Unauthorized
+from keystoneauth1.exceptions.catalog import EndpointNotFound
+from keystoneauth1.exceptions.http import BadRequest, NotFound, Unauthorized
 from notebook.utils import url_escape
 from notebook.base.handlers import APIHandler
 import re
@@ -36,8 +37,7 @@ class SwiftMetadataHandler(SwiftBaseHandler, APIHandler):
                 if not self._is_directory_response(object_response):
                     self._finish_from_swift_response(object_response, object_path)
                     return
-
-            except NotFound:
+            except (NotFound, EndpointNotFound):
                 pass
 
         listing_path = self.api_path('', params)
@@ -61,6 +61,11 @@ class SwiftMetadataHandler(SwiftBaseHandler, APIHandler):
             else:
                 raise
 
+        except EndpointNotFound:
+            region_name = self.swift.region_name
+            raise BadRequest(
+                f'No Swift endpoint exists for region {region_name}')
+
         self._finish_from_swift_response(listing_response, prefix)
 
 
